==> esp8266-0.3.0.crate: esp8266-0.3.0/src/uart1/uart_clkdiv.rs <==
#[doc = "Register `UART_CLKDIV` reader"]
pub struct R(crate::R<UART_CLKDIV_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<UART_CLKDIV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<UART_CLKDIV_SPEC>> for R {
    fn from(reader: crate::R<UART_CLKDIV_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `UART_CLKDIV` writer"]
pub struct W(crate::W<UART_CLKDIV_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<UART_CLKDIV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<UART_CLKDIV_SPEC>> for W {
    fn from(writer: crate::W<UART_CLKDIV_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `uart_clkdiv` reader - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
pub struct UART_CLKDIV_R(crate::FieldReader<u32, u32>);
impl UART_CLKDIV_R {
    pub(crate) fn new(bits: u32) -> Self {
        UART_CLKDIV_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for UART_CLKDIV_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `uart_clkdiv` writer - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
pub struct UART_CLKDIV_W<'a> {
    w: &'a mut W,
}
impl<'a> UART_CLKDIV_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x000f_ffff) | ((value as u32) & 0x000f_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:19 - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
    #[inline(always)]
    pub fn uart_clkdiv(&self) -> UART_CLKDIV_R {
        UART_CLKDIV_R::new((self.bits & 0x000f_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:19 - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
    #[inline(always)]
    pub fn uart_clkdiv(&mut self) -> UART_CLKDIV_W {
        UART_CLKDIV_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "UART CLK DIV REGISTER\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_clkdiv](index.html) module"]
pub struct UART_CLKDIV_SPEC;
impl crate::RegisterSpec for UART_CLKDIV_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [uart_clkdiv::R](R) reader structure"]
impl crate::Readable for UART_CLKDIV_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [uart_clkdiv::W](W) writer structure"]
impl crate::Writable for UART_CLKDIV_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets UART_CLKDIV to value 0"]
impl crate::Resettable for UART_CLKDIV_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/uart1/uart_clkdiv.rs <==
#[doc = "Register `UART_CLKDIV` reader"]
pub struct R(crate::R<UART_CLKDIV_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<UART_CLKDIV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<UART_CLKDIV_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<UART_CLKDIV_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `UART_CLKDIV` writer"]
pub struct W(crate::W<UART_CLKDIV_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<UART_CLKDIV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<UART_CLKDIV_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<UART_CLKDIV_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `uart_clkdiv` reader - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
pub struct UART_CLKDIV_R(crate::FieldReader<u32, u32>);
impl UART_CLKDIV_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        UART_CLKDIV_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for UART_CLKDIV_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `uart_clkdiv` writer - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
pub struct UART_CLKDIV_W<'a> {
    w: &'a mut W,
}
impl<'a> UART_CLKDIV_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x000f_ffff) | (value as u32 & 0x000f_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:19 - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
    #[inline(always)]
    pub fn uart_clkdiv(&self) -> UART_CLKDIV_R {
        UART_CLKDIV_R::new((self.bits & 0x000f_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:19 - BAUDRATE = UART_CLK_FREQ / UART_CLKDIV"]
    #[inline(always)]
    pub fn uart_clkdiv(&mut self) -> UART_CLKDIV_W {
        UART_CLKDIV_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "UART CLK DIV REGISTER\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_clkdiv](index.html) module"]
pub struct UART_CLKDIV_SPEC;
impl crate::RegisterSpec for UART_CLKDIV_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [uart_clkdiv::R](R) reader structure"]
impl crate::Readable for UART_CLKDIV_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [uart_clkdiv::W](W) writer structure"]
impl crate::Writable for UART_CLKDIV_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets UART_CLKDIV to value 0"]
impl crate::Resettable for UART_CLKDIV_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
